<?php
/**
 * Theme hooks.
 * @author  	 DeoThemes
 * @copyright  (c) Copyright by DeoThemes
 * @link       https://deothemes.com
 * @package 	 Xhibiter
 * @since 		 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
 * Head top
 */
function xhibiter_head_top() {
	do_action( 'xhibiter_head_top' );
}

/**
 * Head bottom
 */
function xhibiter_head_bottom() {
	do_action( 'xhibiter_head_bottom' );
}

/**
 * Header before
 */
function xhibiter_header_before() {
	do_action( 'xhibiter_header_before' );
}

/**
 * Site Header
 */
function xhibiter_header() {
	do_action( 'xhibiter_header' );
}

/**
 * Header after
 */
function xhibiter_header_after() {
	do_action( 'xhibiter_header_after' );
}

/**
 * Masthead
 */
function xhibiter_masthead() {
	do_action( 'xhibiter_masthead' );
}

/**
 * Logo before
 */
function xhibiter_logo_before() {
	do_action( 'xhibiter_logo_before' );
}

/**
 * Logo after
 */
function xhibiter_logo_after() {
	do_action( 'xhibiter_logo_after' );
}

/**
 * Menu before
 */
function xhibiter_menu_before() {
	do_action( 'xhibiter_menu_before' );
}

/**
 * Menu after
 */
function xhibiter_menu_after() {
	do_action( 'xhibiter_menu_after' );
}

/**
 * Last menu item after
 */
function xhibiter_last_menu_item_after() {
	do_action( 'xhibiter_last_menu_item_after' );
}

/**
 * Body top
 */
function xhibiter_body_top() {
	do_action( 'xhibiter_body_top' );
}

/**
 * Body bottom
 */
function xhibiter_body_bottom() {
	do_action( 'xhibiter_body_bottom' );
}

/**
 * Primary content top
 */
function xhibiter_primary_content_top() {
	do_action( 'xhibiter_primary_content_top' );
}

/**
 * Primary content before
 */
function xhibiter_primary_content_before() {
	do_action( 'xhibiter_primary_content_before' );
}

/**
 * Primary content query
 */
function xhibiter_primary_content_query() {
	do_action( 'xhibiter_primary_content_query' );
}

/**
 * Primary content after
 */
function xhibiter_primary_content_after() {
	do_action( 'xhibiter_primary_content_after' );
}

/**
 * Primary content bottom
 */
function xhibiter_primary_content_bottom() {
	do_action( 'xhibiter_primary_content_bottom' );
}

/**
 * Comments before
 */
function xhibiter_comments_before() {
	do_action( 'xhibiter_comments_before' );
}

/**
 * Comments
 */
function xhibiter_comments() {
	do_action( 'xhibiter_comments' );
}

/**
 * Comments after
 */
function xhibiter_comments_after() {
	do_action( 'xhibiter_comments_after' );
}

/**
 * Entry section before
 */
function xhibiter_entry_section_before() {
	do_action( 'xhibiter_entry_section_before' );
}


/**
 * Content before
 */
function xhibiter_content_before() {
	do_action( 'xhibiter_content_before' );
}

/**
 * Content top
 */
function xhibiter_content_top() {
	do_action( 'xhibiter_content_top' );
}

/**
 * Content bottom
 */
function xhibiter_content_bottom() {
	do_action( 'xhibiter_content_bottom' );
}

/**
 * Content after
 */
function xhibiter_content_after() {
	do_action( 'xhibiter_content_after' );
}


/**
 * Entry featured image before
 */
function xhibiter_entry_featured_image_before() {
	do_action( 'xhibiter_entry_featured_image_before' );
}

/**
 * Entry featured image
 */
function xhibiter_entry_featured_image() {
	do_action( 'xhibiter_entry_featured_image' );
}

/**
 * Entry featured image after
 */
function xhibiter_entry_featured_image_after() {
	do_action( 'xhibiter_entry_featured_image_after' );
}

/**
 * Entry content top
 */
function xhibiter_entry_content_top() {
	do_action( 'xhibiter_entry_content_top' );
}

/**
 * Entry content bottom
 */
function xhibiter_entry_content_bottom() {
	do_action( 'xhibiter_entry_content_bottom' );
}

/**
 * Page title before
 */
function xhibiter_page_title_before() {
	do_action( 'xhibiter_page_title_before' );
}

/**
 * Page title after
 */
function xhibiter_page_title_after() {
	do_action( 'xhibiter_page_title_after' );
}

/**
 * Sidebar before
 */
function xhibiter_sidebar_before() {
	do_action( 'xhibiter_sidebar_before' );
}

/**
 * Sidebar after
 */
function xhibiter_sidebar_after() {
	do_action( 'xhibiter_sidebar_after' );
}

/**
 * Footer before
 */
function xhibiter_footer_before() {
	do_action( 'xhibiter_footer_before' );
}

/**
 * Footer
 */
function xhibiter_footer() {
	do_action( 'xhibiter_footer' );
}

/**
 * Footer after
 */
function xhibiter_footer_after() {
	do_action( 'xhibiter_footer_after' );
}